[cfe-commits] r151519 - /cfe/trunk/lib/CodeGen/CGDebugInfo.cpp

Eric Christopher echristo at apple.com
Mon Feb 27 00:23:23 PST 2012


Author: echristo
Date: Mon Feb 27 02:23:23 2012
New Revision: 151519

URL: http://llvm.org/viewvc/llvm-project?rev=151519&view=rev
Log:
ObjcInterfaceTypes are also complete types for the type cache.

Fixes rdar://10934887

Modified:
    cfe/trunk/lib/CodeGen/CGDebugInfo.cpp

Modified: cfe/trunk/lib/CodeGen/CGDebugInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/CodeGen/CGDebugInfo.cpp?rev=151519&r1=151518&r2=151519&view=diff
==============================================================================
--- cfe/trunk/lib/CodeGen/CGDebugInfo.cpp (original)
+++ cfe/trunk/lib/CodeGen/CGDebugInfo.cpp Mon Feb 27 02:23:23 2012
@@ -1244,9 +1244,9 @@
                               Line, Size, Align, Flags,
                               llvm::DIArray(), RuntimeLang);
   
-  // Otherwise, insert it into the TypeCache so that recursive uses will find
-  // it.
-  TypeCache[QualType(Ty, 0).getAsOpaquePtr()] = RealDecl;
+  // Otherwise, insert it into the CompletedTypeCache so that recursive uses
+  // will find it and we're emitting the complete type.
+  CompletedTypeCache[QualType(Ty, 0).getAsOpaquePtr()] = RealDecl;
   // Push the struct on region stack.
   llvm::MDNode *MN = RealDecl;
   llvm::TrackingVH<llvm::MDNode> FwdDeclNode = MN;





More information about the cfe-commits mailing list